# -*- coding: utf-8 -*-
# Generated by Django 1.10.4 on 2017-08-29 05:27
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cbr', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='cbrcurrencyrate',
            name='change',
            field=models.DecimalField(decimal_places=4, default=0, max_digits=10, verbose_name='Change'),
            preserve_default=False,
        ),
    ]
